package com.flyfish.framework.query.spi;

import com.flyfish.framework.query.QueryChain;

/**
 * 查询链创建抽象工厂
 * 基于spi提供实现类，最终返回真正实例化的内容
 * 根据引入的jar包自动加载，无需手动处理
 *
 * @author wangyu
 */
public interface QueryChainFactory<C extends QueryChain<C, ?>> {

    /**
     * 生产适配器
     * 此接口为高度抽象接口，目的是兼容更多的查询链类型，便于后续扩展
     *
     * @return 生产结果
     */
    C produce();

    /**
     * 判定是否支持特定的实例类型
     *
     * @param targetType 工厂目标类型
     * @return 是否匹配
     */
    boolean supports(Class<?> targetType);
}
